import React, {useReducer, useEffect} from 'react'
import { validate } from './validator';

const inputReducer = (state, action) => {
  switch (action.type) {
    case 'CHANGE':
      return {
        ...state,
        value: action.val,
        isValid: validate(action.val, action.validators)
      };
    case 'TOUCH': {
      return {
        ...state,
        isTouched: true
      }
    }
    default:
      return state;
  }
};

const Input = props => {
      const[inputState, dispatch] = useReducer(inputReducer, {
        value: props.initialValue || '',
        isTouched: false,
        isValid: props.initialValid || false
      })

      const { id, onInput } = props;
      const { value, isValid } = inputState;

      useEffect(() => {
        onInput(id, value, isValid)
      }, [id, value, isValid, onInput]);


      const inputHandler = (e) =>{
        dispatch({type: 'CHANGE', val: e.target.value, validators: props.validators})
      }

      const touchHandler = () => {
        dispatch({
          type: 'TOUCH'
        });
      };


  const neatInput = 
   props.element === 'input'? (
    <input 
      id={props.id}
      type= {props.type}
      onChange={inputHandler}
      value={inputState.value}
      onBlur={touchHandler}
      placeholder= {props.placeholder}
      />
   ):(
    <textarea 
      onChange={inputHandler}
      value={inputState.value}
      onBlur={touchHandler}
      id={props.id}
      rows={props.rows || 3}
    />
   )
  return (
    <div className={`form-control ${!inputState.isValid && inputState.isTouched &&
      'form-control--invalid'}`}>
       <label htmlFor={props.id}>{props.label}</label>
        {neatInput}
       {!inputState.isValid && inputState.isTouched && <p>{props.errorText}</p>}
    </div>
  )
}

export default Input;